@@ -1,22 +1,21 @@
 from __future__ import annotations
 
 import ast
-import os
 import pkgutil
 import re
 from collections import defaultdict
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    DefaultDict,
-    Iterable,
-    List,
-    Tuple,
-    TypeVar,
-)
+from functools import cached_property
+from typing import Any
+from typing import Callable
+from typing import DefaultDict
+from typing import Iterable
+from typing import List
+from typing import Tuple
+from typing import TYPE_CHECKING
+from typing import TypeVar
 
-from tokenize_rt import Offset, Token
+from tokenize_rt import Offset
+from tokenize_rt import Token
 
 from django_upgrade import fixers
 
@@ -29,13 +28,15 @@ class Settings:
 
 
 admin_re = re.compile(r"(\b|_)admin(\b|_)")
+commands_re = re.compile(r"(^|[\\/])management[\\/]commands[\\/]")
 dunder_init_re = re.compile(r"(^|[\\/])__init__\.py$")
+migrations_re = re.compile(r"(^|[\\/])migrations([\\/])")
 settings_re = re.compile(r"(\b|_)settings(\b|_)")
 test_re = re.compile(r"(\b|_)tests?(\b|_)")
 
 
 class State:
-    __slots__ = ("settings", "filename", "from_imports", "__weakref__")
+    __slots__ = ("settings", "filename", "from_imports", "__weakref__", "__dict__")
 
     def __init__(
         self,
@@ -47,26 +48,27 @@ class State:
         self.filename = filename
         self.from_imports = from_imports
 
+    @cached_property
     def looks_like_admin_file(self) -> bool:
         return admin_re.search(self.filename) is not None
 
+    @cached_property
     def looks_like_command_file(self) -> bool:
-        parts = self.filename.split(os.path.sep)
-        try:
-            i = parts.index("commands")
-        except ValueError:
-            return False
-        return i > 0 and i < (len(parts) - 1) and parts[i - 1] == "management"
+        return commands_re.search(self.filename) is not None
 
+    @cached_property
     def looks_like_dunder_init_file(self) -> bool:
         return dunder_init_re.search(self.filename) is not None
 
+    @cached_property
     def looks_like_migrations_file(self) -> bool:
-        return "migrations" in self.filename.split(os.path.sep)
+        return migrations_re.search(self.filename) is not None
 
+    @cached_property
     def looks_like_settings_file(self) -> bool:
         return settings_re.search(self.filename) is not None
 
+    @cached_property
     def looks_like_test_file(self) -> bool:
         return test_re.search(self.filename) is not None
 
