@@ -10,27 +10,22 @@ from typing import Iterable
 
 from tokenize_rt import Offset
 
-from django_upgrade.ast import ast_start_offset, is_rewritable_import_from
-from django_upgrade.data import Fixer, State, TokenFunc
+from django_upgrade.ast import ast_start_offset
+from django_upgrade.ast import is_rewritable_import_from
+from django_upgrade.data import Fixer
+from django_upgrade.data import State
+from django_upgrade.data import TokenFunc
 from django_upgrade.tokens import update_import_modules
 
 fixer = Fixer(
     __name__,
-    min_version=(1, 11),
+    min_version=(1, 9),
 )
 
 REWRITES = {
-    "django.db.models.fields": {
-        "FieldDoesNotExist": "django.core.exceptions",
-    },
-    "django.db.models.query": {
-        "EmptyResultSet": "django.core.exceptions",
-    },
-    "django.db.models.sql": {
-        "EmptyResultSet": "django.core.exceptions",
-    },
-    "django.db.models.sql.datastructures": {
-        "EmptyResultSet": "django.core.exceptions",
+    "django.forms.forms": {
+        "pretty_name": "django.forms.utils",
+        "BoundField": "django.forms.boundfield",
     },
 }
 
