@@ -11,7 +11,9 @@ from typing import Iterable
 from tokenize_rt import Offset
 
 from django_upgrade.ast import ast_start_offset
-from django_upgrade.data import Fixer, State, TokenFunc
+from django_upgrade.data import Fixer
+from django_upgrade.data import State
+from django_upgrade.data import TokenFunc
 from django_upgrade.tokens import replace
 
 fixer = Fixer(
@@ -27,13 +29,13 @@ def visit_Assign(
     parents: list[ast.AST],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
-        isinstance(parents[-1], ast.ClassDef)
+        state.looks_like_command_file
+        and isinstance(parents[-1], ast.ClassDef)
         and len(node.targets) == 1
         and isinstance(node.targets[0], ast.Name)
         and node.targets[0].id == "requires_system_checks"
         and isinstance(node.value, ast.Constant)
         and (node.value.value is True or node.value.value is False)
-        and state.looks_like_command_file()
     ):
         if node.value.value:
             new_src = '"__all__"'
