@@ -8,18 +8,20 @@ import ast
 from functools import partial
 from typing import Iterable
 
-from tokenize_rt import Offset, Token
+from tokenize_rt import Offset
+from tokenize_rt import Token
 
-from django_upgrade.ast import ast_start_offset, is_rewritable_import_from
-from django_upgrade.data import Fixer, State, TokenFunc
-from django_upgrade.tokens import (
-    CODE,
-    OP,
-    find,
-    find_and_replace_name,
-    parse_call_args,
-    update_import_names,
-)
+from django_upgrade.ast import ast_start_offset
+from django_upgrade.ast import is_rewritable_import_from
+from django_upgrade.data import Fixer
+from django_upgrade.data import State
+from django_upgrade.data import TokenFunc
+from django_upgrade.tokens import CODE
+from django_upgrade.tokens import find
+from django_upgrade.tokens import find_and_replace_name
+from django_upgrade.tokens import OP
+from django_upgrade.tokens import parse_call_args
+from django_upgrade.tokens import update_import_names
 
 fixer = Fixer(
     __name__,
@@ -34,9 +36,9 @@ def visit_ImportFrom(
     parents: list[ast.AST],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
-        is_rewritable_import_from(node)
+        not state.looks_like_migrations_file
+        and is_rewritable_import_from(node)
         and node.module == "django.db.models"
-        and not state.looks_like_migrations_file()
     ):
         yield ast_start_offset(node), partial(
             update_import_names,
@@ -51,7 +53,7 @@ def visit_Call(
     node: ast.Call,
     parents: list[ast.AST],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
-    if (
+    if not state.looks_like_migrations_file and (
         (
             isinstance(node.func, ast.Name)
             and "NullBooleanField" in state.from_imports["django.db.models"]
@@ -64,7 +66,7 @@ def visit_Call(
             and isinstance(node.func.value, ast.Name)
             and node.func.value.id == "models"
         )
-    ) and not state.looks_like_migrations_file():
+    ):
         yield ast_start_offset(node), partial(fix_null_boolean_field, node=node)
 
 
