@@ -10,9 +10,13 @@ from typing import Iterable
 
 from tokenize_rt import Offset
 
-from django_upgrade.ast import ast_start_offset, is_rewritable_import_from
-from django_upgrade.data import Fixer, State, TokenFunc
-from django_upgrade.tokens import find_and_replace_name, update_import_names
+from django_upgrade.ast import ast_start_offset
+from django_upgrade.ast import is_rewritable_import_from
+from django_upgrade.data import Fixer
+from django_upgrade.data import State
+from django_upgrade.data import TokenFunc
+from django_upgrade.tokens import find_and_replace_name
+from django_upgrade.tokens import update_import_names
 
 fixer = Fixer(
     __name__,
