@@ -9,11 +9,18 @@ import sys
 from functools import partial
 from typing import Iterable
 
-from tokenize_rt import Offset, Token
+from tokenize_rt import Offset
+from tokenize_rt import Token
 
 from django_upgrade.ast import ast_start_offset
-from django_upgrade.data import Fixer, State, TokenFunc
-from django_upgrade.tokens import NAME, STRING, find, replace, str_repr_matching
+from django_upgrade.data import Fixer
+from django_upgrade.data import State
+from django_upgrade.data import TokenFunc
+from django_upgrade.tokens import find
+from django_upgrade.tokens import NAME
+from django_upgrade.tokens import replace
+from django_upgrade.tokens import str_repr_matching
+from django_upgrade.tokens import STRING
 
 fixer = Fixer(
     __name__,
@@ -28,7 +35,7 @@ def visit_Subscript(
     parents: list[ast.AST],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
-        not isinstance(parents[-1], ast.Assign)
+        not isinstance(parents[-1], (ast.Assign, ast.Delete))
         and is_request_or_self_request_meta(node.value)
         and (meta_name := extract_constant(node.slice)) is not None
         and (header_name := get_header_name(meta_name)) is not None
