@@ -8,11 +8,15 @@ import ast
 from functools import partial
 from typing import Iterable
 
-from tokenize_rt import Offset, Token
+from tokenize_rt import Offset
+from tokenize_rt import Token
 
 from django_upgrade.ast import ast_start_offset
-from django_upgrade.data import Fixer, State, TokenFunc
-from django_upgrade.tokens import CODE, find_last_token
+from django_upgrade.data import Fixer
+from django_upgrade.data import State
+from django_upgrade.data import TokenFunc
+from django_upgrade.tokens import CODE
+from django_upgrade.tokens import find_last_token
 
 fixer = Fixer(
     __name__,
@@ -27,13 +31,13 @@ def visit_Assign(
     parents: list[ast.AST],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
-        isinstance(parents[-1], ast.ClassDef)
+        state.looks_like_test_file
+        and isinstance(parents[-1], ast.ClassDef)
         and len(node.targets) == 1
         and isinstance(node.targets[0], ast.Name)
         and node.targets[0].id in ("allow_database_queries", "multi_db")
         and isinstance(node.value, ast.Constant)
         and (node.value.value is True or node.value.value is False)
-        and state.looks_like_test_file()
     ):
         yield ast_start_offset(node), partial(
             replace_assignment, node=node, value=node.value.value
