@@ -11,7 +11,9 @@ from typing import Iterable
 from tokenize_rt import Offset
 
 from django_upgrade.ast import ast_start_offset
-from django_upgrade.data import Fixer, State, TokenFunc
+from django_upgrade.data import Fixer
+from django_upgrade.data import State
+from django_upgrade.data import TokenFunc
 from django_upgrade.tokens import erase_node
 
 fixer = Fixer(
@@ -27,12 +29,12 @@ def visit_Assign(
     parents: list[ast.AST],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
-        len(node.targets) == 1
+        state.looks_like_settings_file
+        and len(node.targets) == 1
         and isinstance(node.targets[0], ast.Name)
         and node.targets[0].id == "USE_L10N"
         and isinstance(node.value, ast.Constant)
         and node.value.value is True
         and isinstance(parents[-1], ast.Module)
-        and state.looks_like_settings_file()
     ):
         yield ast_start_offset(node), partial(erase_node, node=node)
